==> alfresco-repository-23.7.0.14-sources.jar: org/alfresco/repo/dictionary/ModelInUseException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.dictionary;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * An exception thrown when an attempt is made to remove a model (or part
 * thereof) when the model is in use. That is, when nodes and node properties
 * reference types, aspects, namespaces, etc in the model.
 * 
 * @author sglover
 *
 */
public class ModelInUseException extends AlfrescoRuntimeException
{
    private static final long serialVersionUID = 1447075542326143577L;

    public ModelInUseException(String message)
    {
        super(message);
    }
}

==> alfresco-repository-25.3.0.70-sources.jar: org/alfresco/repo/dictionary/ModelInUseException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.dictionary;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * An exception thrown when an attempt is made to remove a model (or part thereof) when the model is in use. That is, when nodes and node properties reference types, aspects, namespaces, etc in the model.
 * 
 * @author sglover
 *
 */
public class ModelInUseException extends AlfrescoRuntimeException
{
    private static final long serialVersionUID = 1447075542326143577L;

    public ModelInUseException(String message)
    {
        super(message);
    }
}
